@@ -29,7 +29,7 @@ class test_django(transport.TransportCase):
                             'NAME': ':memory:',
                         },
                     },
-                    INSTALLED_APPS=('kombu.transports.django', ),
+                    INSTALLED_APPS=('kombu.transport.django', ),
                 )
             from django.core.management import call_command
             call_command('syncdb')
